==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/lv-LV/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Lietotājs var pieslēgties sistēmai',
    'activated_disabled_help_text' => 'Jūs nevarat rediģēt sava konta aktivizācijas statusu.',
    'assets_user'       => 'Aktīvi, kas piešķirti: nosaukums',
    'bulk_update_warn'	=> 'Jūs gatavojaties rediģēt lietotāju: user_count īpašības. Lūdzu, ņemiet vērā, ka jūs nevarat mainīt savus lietotāja atribūtus, izmantojot šo veidlapu, un tie ir jārediģē savam lietotājam atsevišķi.',
    'bulk_update_help'	=> 'Šī veidlapa ļauj vienlaikus atjaunināt vairākus lietotājus. Aizpildiet tikai nepieciešamos laukus. Jebkurš tukšs laukums paliek nemainīgs.',
    'current_assets'    => 'Aktīvi, kas pašlaik tiek pārbaudīti šim lietotājam',
    'clone'             => 'Klons lietotājs',
    'contact_user'      => 'Kontaktpersona: vārds',
    'edit'              => 'Rediģēt lietotāju',
    'filetype_info'     => 'Atļautie failu tipi ir png, gif, jpg, jpeg, doc, docx, pdf, txt, zip un rar.',
    'history_user'      => 'Vēsture: vārds',
    'info'				=> 'Info',
    'restore_user'		=> 'Noklikšķiniet šeit, lai tos atjaunotu.',
    'last_login'        => 'Pēdējais pieteikšanās',
    'ldap_config_text'  => 'LDAP konfigurācijas iestatījumus var atrast Admin> Settings. Atlasītā atrašanās vieta (izvēles) tiks iestatīta visiem importētajiem lietotājiem.',
    'print_assigned'    => 'Drukāt izsniegto',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Programmatūra Pārbaudīta: nosaukums',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Apskatīt Lietotāju: vārds',
    'usercsv'           => 'CSV fails',
    'two_factor_admin_optin_help' => 'Jūsu pašreizējie administrēšanas iestatījumi ļauj atlasīt divu faktoru autentifikāciju.',
    'two_factor_enrolled' => 'Reģistrēta 2F ierīce',
    'two_factor_active'   => '2FA aktīvs',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/lv-LV/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Lietotājs var pieslēgties sistēmai',
    'activated_disabled_help_text' => 'Jūs nevarat rediģēt sava konta aktivizācijas statusu.',
    'assets_user'       => 'Aktīvi, kas piešķirti: nosaukums',
    'bulk_update_warn'	=> 'Jūs gatavojaties rediģēt lietotāju: user_count īpašības. Lūdzu, ņemiet vērā, ka jūs nevarat mainīt savus lietotāja atribūtus, izmantojot šo veidlapu, un tie ir jārediģē savam lietotājam atsevišķi.',
    'bulk_update_help'	=> 'Šī veidlapa ļauj vienlaikus atjaunināt vairākus lietotājus. Aizpildiet tikai nepieciešamos laukus. Jebkurš tukšs laukums paliek nemainīgs.',
    'current_assets'    => 'Aktīvi, kas pašlaik tiek pārbaudīti šim lietotājam',
    'clone'             => 'Klons lietotājs',
    'contact_user'      => 'Kontaktpersona: vārds',
    'edit'              => 'Rediģēt lietotāju',
    'filetype_info'     => 'Atļautie failu tipi ir png, gif, jpg, jpeg, doc, docx, pdf, txt, zip un rar.',
    'history_user'      => 'Vēsture: vārds',
    'info'				=> 'Info',
    'restore_user'		=> 'Noklikšķiniet šeit, lai tos atjaunotu.',
    'last_login'        => 'Pēdējais pieteikšanās',
    'ldap_config_text'  => 'LDAP konfigurācijas iestatījumus var atrast Admin> Settings. Atlasītā atrašanās vieta (izvēles) tiks iestatīta visiem importētajiem lietotājiem.',
    'print_assigned'    => 'Drukāt izsniegto',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Programmatūra Pārbaudīta: nosaukums',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Apskatīt Lietotāju: vārds',
    'usercsv'           => 'CSV fails',
    'two_factor_admin_optin_help' => 'Jūsu pašreizējie administrēšanas iestatījumi ļauj atlasīt divu faktoru autentifikāciju.',
    'two_factor_enrolled' => 'Reģistrēta 2F ierīce',
    'two_factor_active'   => '2FA aktīvs',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
